@@ -176,7 +176,9 @@ def serialized_list(olist, **kwargs):
     return [serialized_obj(o, **kwargs) for o in olist]
 
 
-def structured(struct, wrap=True, meta=None, struct_key='result', pre_render_callback=None):
+def structured(struct, wrap=True, meta=None, struct_key=None, pre_render_callback=None):
+    if struct_key is None:
+        struct_key = "result"
     output = struct
     if wrap:
         output = {'status': 'success', struct_key: struct}
@@ -187,7 +189,7 @@ def structured(struct, wrap=True, meta=None, struct_key='result', pre_render_cal
     return output
 
 
-def jsoned(struct, wrap=True, meta=None, struct_key='result', pre_render_callback=None):
+def jsoned(struct, wrap=True, meta=None, struct_key=None, pre_render_callback=None):
     """ Provides a json dump of the struct
 
     Args:
@@ -233,11 +235,14 @@ def jsoned_list(olist, **kwargs):
         serializable_list(olist, **kwargs))
 
 
-def as_json(struct, status=200, wrap=True, meta=None, pre_render_callback=None):
+def as_json(
+        struct, status=200, wrap=True, meta=None, 
+        pre_render_callback=None, struct_key=None):
     return Response(
         jsoned(
             struct, wrap=wrap, meta=meta,
-            pre_render_callback=pre_render_callback),
+            pre_render_callback=pre_render_callback,
+            struct_key=struct_key),
         status, mimetype='application/json')
 
 def as_dict(o, attrs_to_serialize=None,
@@ -331,6 +336,20 @@ def success_json():
                     200, mimetype='application/json')
 
 
+def convert_error_to_json_response(e):
+    response = e.get_response()
+    response.data = _json.dumps({
+        "status": "failure",
+        "error": {
+            "code": e.code,
+            "name": e.name,
+            "description": e.description
+        }
+    })
+    response.content_type = "application/json"
+    return response
+
+
 def error_json(status_code, error=None):
     return Response(_json.dumps({
         'status': 'failure',
@@ -489,9 +508,7 @@ def return_joined_query_model_class_and_attr_name(query, keyword):
                     if model_class not in [entity.class_ for entity in _query._join_entities]:
                         # print("About to join model_class ", model_class)
                         # print("rel_or_proxy_name is ", rel_or_proxy_name)
-                        # try:
-                        #     _query = _query.join(model_class)
-                        # except:
+                        # _query = _query.join(model_class)
                         _query = _query.join(rel_or_proxy_name)
                 elif rel_or_proxy_name in model_class.association_proxy_keys():
                     assoc_proxy = getattr(model_class, rel_or_proxy_name)
@@ -537,7 +554,9 @@ def return_joined_query_model_class_and_attr_name(query, keyword):
 
 
 def modify_query_and_get_filter_function(query, keyword, value, op):
-    # print("in modify_query_and_get_filter_function")
+    # print(
+    #     "in modify_query_and_get_filter_function ",
+    #     query, keyword, value, op)
     _query, model_class, attr_name = return_joined_query_model_class_and_attr_name(query, keyword)
     # print("in modify query, model_class ", model_class)
     # print("in modify query, attr_name ", attr_name)
@@ -596,13 +615,15 @@ def filter_query_with_key(query, keyword, value, op):
 
 
 def convert_filters_to_sqlalchemy_filter(query, filters, connector):
-    # print("in convert_filters_to_sqlalchemy_filter")
+    # print(
+    #     "in convert_filters_to_sqlalchemy_filter ", 
+    #     query, filters, connector)
     sqfilters = []
     for f in filters:
         # print("checking filter ", f)
         if "c" in f:
             # print("found a connector c in filter")
-            sub_sq_filter = convert_filters_to_sqlalchemy_filter(
+            query, sub_sq_filter = convert_filters_to_sqlalchemy_filter(
                 query, f['f'], f['c'])
             if sub_sq_filter is not None:
                 sqfilters.append(sub_sq_filter)
@@ -610,14 +631,15 @@ def convert_filters_to_sqlalchemy_filter(query, filters, connector):
             # print("calling modify_query")
             query, sqfilter = modify_query_and_get_filter_function(
                 query, f["k"], f["v"], f["op"])
+
             sqfilters.append(sqfilter)
     # print("found sqfilters list as ", sqfilters)
     if len(sqfilters) > 0:
         if connector == 'AND':
-            return and_(*sqfilters)
+            return (query, and_(*sqfilters))
         if connector == 'OR':
-            return or_(*sqfilters)
-    return None
+            return (query, or_(*sqfilters))
+    return (query, None)
 
 
 def filter_query_using_filters_list(result, filters_dict):
@@ -661,7 +683,8 @@ def filter_query_using_filters_list(result, filters_dict):
             result = result.query
     filters = filters_dict['f']
     connector = filters_dict.get('c') or 'AND'
-    sqfilter = convert_filters_to_sqlalchemy_filter(result, filters, connector)
+    result, sqfilter = convert_filters_to_sqlalchemy_filter(
+        result, filters, connector)
     if sqfilter is not None:
         result = result.filter(sqfilter)
     # print("sqlalchemy filters ", result)
